@@ -390,7 +390,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.76'
+__version__ = '0.2.77'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -1002,17 +1002,6 @@ class MainAppBase(ConsoleApp, ABC):
             flow_path = self.flow_path
         return flow_action(flow_path_id(flow_path=flow_path, path_index=path_index))
 
-    def font_min_max_size_from_win(self, win_width: float, win_height: float) -> Tuple[float, float]:
-        """ calculate optimal range of font size depending on the window/screen resolution.
-
-        :param win_width:       window/screen width in pixels.
-        :param win_height:      window/screen height in pixels.
-        :return:                minimum and maximum font size in pixels.
-        """
-        min_len = min(win_width, win_height) * self.dpi_factor()
-        return (min(max(MIN_FONT_SIZE, round(min_len / 48.9)), MAX_FONT_SIZE),
-                min(max(MIN_FONT_SIZE, round(min_len / 24.6)), MAX_FONT_SIZE))
-
     def global_variables(self, **patches) -> Dict[str, Any]:
         """ determine generic/most-needed global variables to evaluate expressions/macros.
 
@@ -1402,12 +1391,8 @@ class MainAppBase(ConsoleApp, ABC):
         self.vpo(f"MainAppBase.setup_app_states {app_states}")
 
         font_size = app_states.get('font_size', 0)
-        win_width, win_height = app_states.get('win_rectangle', (0, 0, 1920, 1080))[2:]
         if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:   # adopt device scaling on very first app start
-            if font_size == -1.0:
-                min_f, max_f = self.font_min_max_size_from_win(win_width, win_height)
-                font_size = min_f + (max_f - min_f) / 3.0
-            elif font_size < 0.0:
+            if font_size < 0.0:
                 font_size = self.dpi_factor() * -font_size
             app_states['font_size'] = min(max(MIN_FONT_SIZE, font_size), MAX_FONT_SIZE)
 
@@ -1524,14 +1509,7 @@ class MainAppBase(ConsoleApp, ABC):
         win_width, win_height = win_pos_size[2:]
         app.landscape = win_width >= win_height                 # update landscape flag
 
-        font_size = self.font_size
-        min_f, max_f = self.font_min_max_size_from_win(win_width, win_height)
-        if not min_f <= font_size <= max_f:
-            self.change_app_state('font_size', min(max(min_f, font_size), max_f))
-        app.max_font_size = max_f                               # update dynamic min/max font size
-        app.min_font_size = min_f
-
-        self.vpo(f"MainAppBase.win_pos_size_change {win_pos_size}: landscape={app.landscape} font size={min_f}-{max_f}")
+        self.vpo(f"MainAppBase.win_pos_size_change {win_pos_size}: landscape={app.landscape}")
 
         self.change_app_state('win_rectangle', win_pos_size)
         self.call_method('on_win_pos_size')
